==> thunderbird_66.0~b1.orig.tar.xz: thunderbird-66.0/browser/components/newtab/prerendered/locales/hr/activity-stream-strings.js <==
// Note - this is a generated hr file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Nova kartica",
  "header_top_sites": "Najbolje stranice",
  "header_highlights": "Istaknuto",
  "header_recommended_by": "Preporučeno od {provider}",
  "context_menu_button_sr": "Otvorite kontekstni izbornik za {title}",
  "section_context_menu_button_sr": "Otvorite kontekstni izbornik odjela",
  "type_label_visited": "Posjećeno",
  "type_label_bookmarked": "Zabilježeno",
  "type_label_recommended": "Popularno",
  "type_label_pocket": "Spremljeno u Pocket",
  "type_label_downloaded": "Preuzeto",
  "menu_action_bookmark": "Zabilježi stranicu",
  "menu_action_remove_bookmark": "Ukloni zabilješku",
  "menu_action_open_new_window": "Otvori u novom prozoru",
  "menu_action_open_private_window": "Otvori u novom privatnom prozoru",
  "menu_action_dismiss": "Odbaci",
  "menu_action_delete": "Obriši iz povijesti",
  "menu_action_pin": "Zakači",
  "menu_action_unpin": "Otkači",
  "confirm_history_delete_p1": "Jeste li sigurni da želite obrisati sve primjere ove stranice iz vaše povijesti?",
  "confirm_history_delete_notice_p2": "Ova radnja je nepovratna.",
  "menu_action_save_to_pocket": "Spremi u Pocket",
  "menu_action_delete_pocket": "Izbriši iz Pocketa",
  "menu_action_archive_pocket": "Arhiviraj u Pocket",
  "menu_action_show_file_mac_os": "Prikaži u Finder-u",
  "menu_action_show_file_windows": "Otvori sadržajnu mapu",
  "menu_action_show_file_linux": "Otvori sadržajnu mapu",
  "menu_action_show_file_default": "Prikaži datoteku",
  "menu_action_open_file": "Otvori datoteku",
  "menu_action_copy_download_link": "Kopiraj poveznicu preuzimanja",
  "menu_action_go_to_download_page": "Idi na stranicu preuzimanja",
  "menu_action_remove_download": "Ukloni iz povijesti",
  "search_button": "Traži",
  "search_header": "{search_engine_name} pretraživanje",
  "search_web_placeholder": "Pretraži web",
  "section_disclaimer_topstories": "Najzanimljivije priče na internetu, odabrane na temelju onog što ste pročitali. Iz Pocket-a, sada dio Mozille.",
  "section_disclaimer_topstories_linktext": "Saznajte kako funkcionira.",
  "section_disclaimer_topstories_buttontext": "U redu, razumijem",
  "prefs_home_header": "Firefox početni sadržaj",
  "prefs_home_description": "Odaberite koji sadržaj želite na vašoj Firefox početnoj stranici.",
  "prefs_content_discovery_header": "Firefox Home",
  "prefs_content_discovery_description": "Content Discovery in Firefox Home allows you to discover high-quality, relevant articles from across the web.",
  "prefs_content_discovery_button": "Turn Off Content Discovery",
  "prefs_section_rows_option": "{num} red;{num} reda;{num} reda",
  "prefs_search_header": "Web pretraživanje",
  "prefs_topsites_description": "Stranice koje najviše posjećujete",
  "prefs_topstories_description2": "Vrhunski sadržaj iz svih krajeva interneta, presonaliziran za vas",
  "prefs_topstories_options_sponsored_label": "Sponzorirane priče",
  "prefs_topstories_sponsored_learn_more": "Saznajte više",
  "prefs_highlights_description": "Izbor stranica koje ste spremili ili posjetili",
  "prefs_highlights_options_visited_label": "Posjećene stranice",
  "prefs_highlights_options_download_label": "Najnovije preuzimanje",
  "prefs_highlights_options_pocket_label": "Stranice spremljene u Pocket",
  "prefs_snippets_description": "Ažuriranja od Mozille i Firefoxa",
  "settings_pane_button_label": "Prilagodite svoju početnu stranicu nove kartice",
  "settings_pane_topsites_header": "Najbolje stranice",
  "settings_pane_highlights_header": "Istaknuto",
  "settings_pane_highlights_options_bookmarks": "Zabilješke",
  "settings_pane_snippets_header": "Isječci",
  "edit_topsites_button_text": "Uredi",
  "edit_topsites_edit_button": "Uredi ovu stranicu",
  "topsites_form_add_header": "Nova najbolja stranica",
  "topsites_form_edit_header": "Uredi najbolju stranicu",
  "topsites_form_title_label": "Naslov",
  "topsites_form_title_placeholder": "Unesi naslov",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "Prilagođeni URL slike",
  "topsites_form_url_placeholder": "Utipkajte ili zalijepite URL",
  "topsites_form_use_image_link": "Koristi prilagođenu sliku…",
  "topsites_form_preview_button": "Pregled",
  "topsites_form_add_button": "Dodaj",
  "topsites_form_save_button": "Spremi",
  "topsites_form_cancel_button": "Otkaži",
  "topsites_form_url_validation": "Potrebno je unijeti ispravan URL",
  "topsites_form_image_validation": "Neuspjelo učitavanje slike. Pokušajte drugi URL.",
  "pocket_read_more": "Popularne teme:",
  "pocket_read_even_more": "Prikaži više priča",
  "pocket_more_reccommendations": "Više preporuka",
  "pocket_how_it_works": "Kako ovo funkcionira",
  "pocket_cta_button": "Nabavite Pocket",
  "pocket_cta_text": "Spremite priče koje vam se sviđaju u Pocket i napajajte vaš um s vrhunskim štivom.",
  "highlights_empty_state": "Započnite pretraživati i pokazat ćemo vam neke od izvrsnih članaka, videa i drugih web stranica prema vašim nedavno posjećenim stranicama ili zabilješkama.",
  "topstories_empty_state": "Provjerite kasnije za više najpopularnijih priča od {provider}. Ne možete čekati? Odaberite popularne teme kako biste pronašli više kvalitetnih priča s cijelog weba.",
  "manual_migration_explanation2": "Probajte Firefox s zabilješkama, povijesti i lozinkama iz drugog pretraživača.",
  "manual_migration_cancel_button": "Ne hvala",
  "manual_migration_import_button": "Uvezi sada",
  "error_fallback_default_info": "Došlo je do greške prilikom učitavanja ovog sadržaja.",
  "error_fallback_default_refresh_suggestion": "Osvježite stranicu da biste pokušali ponovno.",
  "section_menu_action_remove_section": "Ukloni odjel",
  "section_menu_action_collapse_section": "Skupi odjel",
  "section_menu_action_expand_section": "Proširi odjel",
  "section_menu_action_manage_section": "Upravljanje odjelom",
  "section_menu_action_manage_webext": "Upravljanje dodatkom",
  "section_menu_action_add_topsite": "Dodaj najbolju stranicu",
  "section_menu_action_add_search_engine": "Dodaj tražilicu",
  "section_menu_action_move_up": "Pomakni gore",
  "section_menu_action_move_down": "Pomakni dolje",
  "section_menu_action_privacy_notice": "Politika privatnosti",
  "firstrun_title": "Uzmite Firefox sa sobom",
  "firstrun_content": "Preuzmite svoje zabilješke, povijest, lozinke i druge postavke na sve vaše uređaje.",
  "firstrun_learn_more_link": "Saznajte više o Firefox računima",
  "firstrun_form_header": "Unesite vašu adresu e-pošte",
  "firstrun_form_sub_header": "i prijavi se u Firefox Sync",
  "firstrun_email_input_placeholder": "E-pošta",
  "firstrun_invalid_input": "Potrebna je ispravna adresa e-pošte",
  "firstrun_extra_legal_links": "Nastavljanjem pristajete na {terms} i {privacy}.",
  "firstrun_terms_of_service": "Uvjete korištenja",
  "firstrun_privacy_notice": "Politiku privatnosti",
  "firstrun_continue_to_login": "Nastavi",
  "firstrun_skip_login": "Preskočite ovaj korak",
  "context_menu_title": "Otvori izbornik"
};

==> thunderbird_68.5.0.orig.tar.xz: thunderbird-68.5.0/browser/components/newtab/prerendered/locales/hr/activity-stream-strings.js <==
// Note - this is a generated hr file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Nova kartica",
  "header_top_sites": "Najbolje stranice",
  "header_highlights": "Istaknuto",
  "header_recommended_by": "Preporučeno od {provider}",
  "context_menu_button_sr": "Otvorite kontekstni izbornik za {title}",
  "section_context_menu_button_sr": "Otvorite kontekstni izbornik odjela",
  "type_label_visited": "Posjećeno",
  "type_label_bookmarked": "Zabilježeno",
  "type_label_recommended": "Popularno",
  "type_label_pocket": "Spremljeno u Pocket",
  "type_label_downloaded": "Preuzeto",
  "menu_action_bookmark": "Zabilježi stranicu",
  "menu_action_remove_bookmark": "Ukloni zabilješku",
  "menu_action_open_new_window": "Otvori u novom prozoru",
  "menu_action_open_private_window": "Otvori u novom privatnom prozoru",
  "menu_action_dismiss": "Odbaci",
  "menu_action_delete": "Obriši iz povijesti",
  "menu_action_pin": "Zakači",
  "menu_action_unpin": "Otkači",
  "confirm_history_delete_p1": "Jeste li sigurni da želite obrisati sve primjere ove stranice iz vaše povijesti?",
  "confirm_history_delete_notice_p2": "Ova radnja je nepovratna.",
  "menu_action_save_to_pocket": "Spremi u Pocket",
  "menu_action_delete_pocket": "Izbriši iz Pocketa",
  "menu_action_archive_pocket": "Arhiviraj u Pocket",
  "menu_action_show_file_mac_os": "Prikaži u Finder-u",
  "menu_action_show_file_windows": "Otvori sadržajnu mapu",
  "menu_action_show_file_linux": "Otvori sadržajnu mapu",
  "menu_action_show_file_default": "Prikaži datoteku",
  "menu_action_open_file": "Otvori datoteku",
  "menu_action_copy_download_link": "Kopiraj poveznicu preuzimanja",
  "menu_action_go_to_download_page": "Idi na stranicu preuzimanja",
  "menu_action_remove_download": "Ukloni iz povijesti",
  "search_button": "Traži",
  "search_header": "{search_engine_name} pretraživanje",
  "search_web_placeholder": "Pretraži web",
  "section_disclaimer_topstories": "Najzanimljivije priče na internetu, odabrane na temelju onog što ste pročitali. Iz Pocket-a, sada dio Mozille.",
  "section_disclaimer_topstories_linktext": "Saznajte kako funkcionira.",
  "section_disclaimer_topstories_buttontext": "U redu, razumijem",
  "prefs_home_header": "Firefox početni sadržaj",
  "prefs_home_description": "Odaberite koji sadržaj želite na vašoj Firefox početnoj stranici.",
  "prefs_content_discovery_description": "Otkrivanje sadržaja u Firefox početnoj stranici pomaže vam u otkrivanju visoko kvalitenih, relevantnih članaka diljem interneta.",
  "prefs_section_rows_option": "{num} red;{num} reda;{num} reda",
  "prefs_search_header": "Web pretraživanje",
  "prefs_topsites_description": "Stranice koje najviše posjećujete",
  "prefs_topstories_description2": "Vrhunski sadržaj iz svih krajeva interneta, presonaliziran za vas",
  "prefs_topstories_options_sponsored_label": "Sponzorirane priče",
  "prefs_topstories_sponsored_learn_more": "Saznajte više",
  "prefs_highlights_description": "Izbor stranica koje ste spremili ili posjetili",
  "prefs_highlights_options_visited_label": "Posjećene stranice",
  "prefs_highlights_options_download_label": "Najnovije preuzimanje",
  "prefs_highlights_options_pocket_label": "Stranice spremljene u Pocket",
  "prefs_snippets_description": "Ažuriranja od Mozille i Firefoxa",
  "settings_pane_button_label": "Prilagodite svoju početnu stranicu nove kartice",
  "settings_pane_topsites_header": "Najbolje stranice",
  "settings_pane_highlights_header": "Istaknuto",
  "settings_pane_highlights_options_bookmarks": "Zabilješke",
  "settings_pane_snippets_header": "Isječci",
  "edit_topsites_button_text": "Uredi",
  "edit_topsites_edit_button": "Uredi ovu stranicu",
  "topsites_form_add_header": "Nova najbolja stranica",
  "topsites_form_edit_header": "Uredi najbolju stranicu",
  "topsites_form_title_label": "Naslov",
  "topsites_form_title_placeholder": "Unesi naslov",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "Prilagođeni URL slike",
  "topsites_form_url_placeholder": "Utipkajte ili zalijepite URL",
  "topsites_form_use_image_link": "Koristi prilagođenu sliku…",
  "topsites_form_preview_button": "Pregled",
  "topsites_form_add_button": "Dodaj",
  "topsites_form_save_button": "Spremi",
  "topsites_form_cancel_button": "Otkaži",
  "topsites_form_url_validation": "Potrebno je unijeti ispravan URL",
  "topsites_form_image_validation": "Neuspjelo učitavanje slike. Pokušajte drugi URL.",
  "pocket_read_more": "Popularne teme:",
  "pocket_read_even_more": "Prikaži više priča",
  "pocket_more_reccommendations": "Više preporuka",
  "pocket_how_it_works": "Kako ovo funkcionira",
  "pocket_cta_button": "Nabavite Pocket",
  "pocket_cta_text": "Spremite priče koje vam se sviđaju u Pocket i napajajte vaš um s vrhunskim štivom.",
  "highlights_empty_state": "Započnite pretraživati i pokazat ćemo vam neke od izvrsnih članaka, videa i drugih web stranica prema vašim nedavno posjećenim stranicama ili zabilješkama.",
  "topstories_empty_state": "Provjerite kasnije za više najpopularnijih priča od {provider}. Ne možete čekati? Odaberite popularne teme kako biste pronašli više kvalitetnih priča s cijelog weba.",
  "error_fallback_default_info": "Došlo je do greške prilikom učitavanja ovog sadržaja.",
  "error_fallback_default_refresh_suggestion": "Osvježite stranicu da biste pokušali ponovno.",
  "section_menu_action_remove_section": "Ukloni odjel",
  "section_menu_action_collapse_section": "Skupi odjel",
  "section_menu_action_expand_section": "Proširi odjel",
  "section_menu_action_manage_section": "Upravljanje odjelom",
  "section_menu_action_manage_webext": "Upravljanje dodatkom",
  "section_menu_action_add_topsite": "Dodaj najbolju stranicu",
  "section_menu_action_add_search_engine": "Dodaj tražilicu",
  "section_menu_action_move_up": "Pomakni gore",
  "section_menu_action_move_down": "Pomakni dolje",
  "section_menu_action_privacy_notice": "Politika privatnosti",
  "firstrun_title": "Uzmite Firefox sa sobom",
  "firstrun_content": "Preuzmite svoje zabilješke, povijest, lozinke i druge postavke na sve vaše uređaje.",
  "firstrun_learn_more_link": "Saznajte više o Firefox računima",
  "firstrun_form_header": "Unesite vašu adresu e-pošte",
  "firstrun_form_sub_header": "i prijavi se u Firefox Sync",
  "firstrun_email_input_placeholder": "E-pošta",
  "firstrun_invalid_input": "Potrebna je ispravna adresa e-pošte",
  "firstrun_extra_legal_links": "Nastavljanjem pristajete na {terms} i {privacy}.",
  "firstrun_terms_of_service": "Uvjete korištenja",
  "firstrun_privacy_notice": "Politiku privatnosti",
  "firstrun_continue_to_login": "Nastavi",
  "firstrun_skip_login": "Preskočite ovaj korak",
  "context_menu_title": "Otvori izbornik"
};
